@@ -204,7 +204,7 @@ def test_star_wars(capfd):
     expected = '''
     from dataclasses import dataclass
     from datetime import datetime
-    from typing import Dict, List, Union
+    from typing import List, Union
 
 
     @dataclass
@@ -222,7 +222,7 @@ def test_star_wars(capfd):
         terrain: str
         surface_water: Union[int, str]
         population: Union[int, str]
-        residents: Dict
+        residents: List
         films: List[str]
         created: datetime
         edited: datetime
